@@ -33,7 +33,7 @@ class Cell:
         elif cell_value.type == TSTArchives.textCellType:
             cell = TextCell(row_num, col_num, cell_value.value)
         elif cell_value.type == TSTArchives.dateCellType:
-            cell = DateCell(row_num, col_num, cell_value.value)
+            cell = DateCell(row_num, col_num, cell_value.value, cell_value.formatted)
         elif cell_value.type == TSTArchives.boolCellType:
             cell = BoolCell(row_num, col_num, cell_value.value)
         elif cell_value.type == TSTArchives.durationCellType:
@@ -41,7 +41,10 @@ class Cell:
                 cell = DurationCell(row_num, col_num, timedelta(seconds=0))
             else:
                 cell = DurationCell(
-                    row_num, col_num, timedelta(seconds=cell_value.value)
+                    row_num,
+                    col_num,
+                    timedelta(seconds=cell_value.value),
+                    cell_value.formatted,
                 )
         elif cell_value.type == TSTArchives.formulaErrorCellType:
             cell = ErrorCell(row_num, col_num, None)
@@ -76,6 +79,7 @@ class Cell:
         self.size = (1, 1)
         self.is_merged = False
         self.is_bulleted = False
+        self.formatted_value = None
 
     @property
     def formula(self):
@@ -187,9 +191,10 @@ class BoolCell(Cell):
 
 
 class DateCell(Cell):
-    def __init__(self, row_num: int, col_num: int, value):
+    def __init__(self, row_num: int, col_num: int, value, formatted_value=None):
         self._type = TSTArchives.dateCellType
         super().__init__(row_num, col_num, value)
+        self.formatted_value = formatted_value
 
     @property
     def value(self) -> timedelta:
@@ -197,9 +202,10 @@ class DateCell(Cell):
 
 
 class DurationCell(Cell):
-    def __init__(self, row_num: int, col_num: int, value):
+    def __init__(self, row_num: int, col_num: int, value, formatted_value=None):
         self._type = TSTArchives.durationCellType
         super().__init__(row_num, col_num, value)
+        self.formatted_value = formatted_value
 
     @property
     def value(self) -> timedelta:
